@@ -1,3 +1,2 @@
-from xmp2jsonforybigta import *
-
+from .xmp2jsonforybigta import *
 from .__version__ import __version__
\ No newline at end of file
