@@ -1,7 +1,11 @@
-def convert(infile):
+import json
+import re
+def convert(infile,jsonfile):
     fin = open(infile, "r")
     lines = fin.readlines()
     lines = lines[7:]
+    with open(jsonfile, 'r') as f:
+        json_data = json.load(f)
 
     preset_list = []
 
